@@ -1,6 +1,6 @@
 #' Construction function for class "Emissions"
 #'
-#' @description \code{Emissions} returns a tranformed object with class "Emissions".
+#' @description \code{Emissions} returns a transformed object with class "Emissions".
 #' The type of objects supported are of classes "matrix", "data.frame" and
 #' "numeric". If the class of the object is "matrix" this function returns a
 #' dataframe.
@@ -104,7 +104,7 @@ Emissions <- function(x, mass = "g", time, ...) {
 
     class(e) <- c("Emissions",class(x))
 
-  } else if ( class(x) == "units" ) {
+  } else if ( inherits(x, "units" )) {
 
     e <- x
 
@@ -116,7 +116,7 @@ Emissions <- function(x, mass = "g", time, ...) {
     }
 
 
-  } else if( class(x) == "numeric" | class(x) == "integer") {
+  } else if( inherits(x, "numeric") | inherits(x, "integer")) {
 
     e <- x*units::as_units("g")
 
